Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(447)

Unified Diff: test/mjsunit/es6/debug-promises/throw-finally-caught-all.js

Issue 2197183002: [debugger] use handler table on unoptimized code for exception prediction. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: address comments and rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/objects-inl.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/mjsunit/es6/debug-promises/throw-finally-caught-all.js
diff --git a/test/mjsunit/es6/debug-promises/throw-caught-all.js b/test/mjsunit/es6/debug-promises/throw-finally-caught-all.js
similarity index 88%
copy from test/mjsunit/es6/debug-promises/throw-caught-all.js
copy to test/mjsunit/es6/debug-promises/throw-finally-caught-all.js
index 3b7c48c1cff2ab8b96622cf2f52733a32683bffd..a3d45dce7798a8a04fa33ea6663cd2df04472109 100644
--- a/test/mjsunit/es6/debug-promises/throw-caught-all.js
+++ b/test/mjsunit/es6/debug-promises/throw-finally-caught-all.js
@@ -1,11 +1,12 @@
-// Copyright 2014 the V8 project authors. All rights reserved.
+// Copyright 2016 the V8 project authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
// Flags: --expose-debug-as debug --allow-natives-syntax --promise-extra
// Test debug events when we listen to all exceptions and
// there is a catch handler for the exception thrown in a Promise.
// We expect a normal Exception debug event to be triggered.
Debug = debug.Debug;
@@ -21,7 +22,10 @@ var p = new Promise(function(resolve, reject) {
var q = p.chain(
function() {
log.push("throw");
- throw new Error("caught");
+ try {
+ throw new Error("caught");
+ } finally {
+ }
});
q.catch(
« no previous file with comments | « src/objects-inl.h ('k') | no next file » | no next file with comments »
@@ -1,11 +1,12 @@
// Flags: --expose-debug-as debug --allow-natives-syntax --promise-extra
// Test debug events when we listen to all exceptions and
-// there is a catch handler for the exception thrown in a Promise.
+// there is a catch handler for the exception thrown in a Promise, first
+// caught by a try-finally, and immediately rethrown.
// We expect a normal Exception debug event to be triggered.
Debug = debug.Debug;

Powered by Google App Engine
This is Rietveld 408576698